# Default Configuration

This configuration applies to every run of AutoRest, but with less priority than any other specified configuration (i.e. it is overridable).

## Basic Settings

```yaml
azure-arm: false
output-folder: generated
openapi-type: arm

# Load additional configurations.
require:
  - $(this-folder)inspect.md
  - $(this-folder)directives.md
  - $(this-folder)pipeline.md
  - $(this-folder)loader-openapi.md
  - $(this-folder)miscellaneous.md
  - $(this-folder)plugin-powershell.md
  - $(this-folder)plugin-azureresourceschema.md
  - $(this-folder)plugin-csharp.md
  - $(this-folder)plugin-go.md
  - $(this-folder)plugin-java.md
  - $(this-folder)plugin-nodejs.md
  - $(this-folder)plugin-php.md
  - $(this-folder)plugin-python.md
  - $(this-folder)plugin-ruby.md
  - $(this-folder)plugin-typescript.md
  - $(this-folder)plugin-validators.md
  - $(this-folder)plugin-az.md
  - $(this-folder)plugin-terraform.md
  - $(this-folder)plugin-azure-functions.md
  - $(this-folder)plugin-openapi-to-cadl.md

  - $(this-folder)graphs.md
  - $(this-folder)help-configuration.md
```

##### Extra configuration for `azure-arm: true`

These extra settings are applied when `azure-arm: true`:

```yaml $(azure-arm)
head-as-boolean: true
```

##### Extra configuration for `legacy `

If `--legacy` isn't provided, we set the `track2` option to `true` to indicate
to V3 generators that the user wants to generate a Track 2 library.

```yaml !$(legacy)
track2: true
```

##### Actually load files

If we don't specify `--help`, we will trigger the setting to load files

```yaml enableAllVersionsMode()
# when an autorest-v3 generator is loading, and a profile or api-verison is specified,
# we need to force the tag: all-api-versions so that it loads the whole api set.
# but not TOO high, as then it'll be evaluated before $(pipeline-model)
tag: all-api-versions
load-priority: 500
```

```yaml
header-definitions:
  warning: Changes may cause incorrect behavior and will be lost if the code is regenerated.

  default: "Code generated by Microsoft (R) AutoRest Code Generator (autorest: {core}, generator: {generator})"

  no-version: Code generated by Microsoft (R) AutoRest Code Generator.

  apache: |
    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at
      http://www.apache.org/licenses/LICENSE-2.0
    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

  mit: Licensed under the MIT License. See License.txt in the project root for license information.

  mit-small: Licensed under the MIT License.

  microsoft: Copyright (c) Microsoft Corporation. All rights reserved.
```
